:mod:`euphorie.content.module`
==============================

.. automodule:: euphorie.content.module

.. autointerface:: IModule
   :members:

.. autoclass:: Module

.. autofunction:: tree_depth

.. autofunction:: item_depth

.. autofunction:: SearchableTextIndexer

.. autoclass:: ConstructionFilter
   :members:


Views
-----

.. autoclass:: View
   :members:

.. autoclass:: Edit




